pub enum ReportError {
Reported {
filename: String,
line: u32,
column: u32,
msg: String,
},
Other {
msg: String,
},
}Expand description
An auxiliary datatype used by report_error to be able to
retain the structured information in case we want to use it later
to insert proper links to the file, or other formatting.
Variants
Reported
An error reported by report_error
Other
Some other source of error. We only have the description, and no location.