pub enum VersionedBuildInfo {
V0(BuildInfo),
}Expand description
A versioned build information. This is the information that is embedded in a custom section. Currently there is one version, but the format supports future evolution.
The value is embedded in a custom section serialized using the smart
contract serialization format
(Serial trait).
Variants