BuildInfo

Struct BuildInfo 

pub struct BuildInfo {
    pub archive_hash: Hash,
    pub source_link: Option<String>,
    pub image: String,
    pub build_command: Vec<String>,
}
The build information that will be embedded as a custom section to support reproducible builds.

Fields

archive_hash: Hash

The SHA256 hash of the tar file used to build. Note that this is the hash of the tar file alone, not of any compressed version.

source_link: Option<String>

The link to where the source code will be located.

image: String

The build image that was used.

build_command: Vec<String>

The exact command invocation inside the image that was used to produce the contract.