TestHost

Struct TestHost 

pub struct TestHost<'a, R, BackingStore> {
    pub rng_used: bool,
    pub debug_events: Vec<EmittedDebugStatement>,
    /* private fields */
}
A host which traps for any function call apart from report_error which it prints to standard out and get_random that calls a random number generator.

Fields

rng_used: bool

A flag set to true if the RNG was used.

debug_events: Vec<EmittedDebugStatement>

Debug statements in the order they were emitted.

Implementations

Source

impl<'a, R: RngCore, BackingStore> TestHost<'a, R, BackingStore>

pub fn new(rng: R, state: InstanceState<'a, BackingStore>) -> Self

Create a new TestHost instance with the given RNG, set the flag to unused, no debug events and use the provided instance state for state-related host function calls.